==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesKy.php <==
<?php
/** Kirghiz (Кыргызча)
 *
 * @ingroup Language
 * @file
 *
 * @author Aidabishkek
 */

$messages = array(
'underline-always' => 'Ар дайым',
'underline-never'  => 'Эч качан',

# Dates
'sunday'    => 'Жекшемби',
'monday'    => 'Дүйшөмбү',
'tuesday'   => 'Шейшемби',
'wednesday' => 'Шаршемби',
'thursday'  => 'Бейшемби',
'friday'    => 'Жума',
'saturday'  => 'Ишемби',
'wed'       => 'Шарш.',
'january'   => 'Январь (Үчтүн айы)',
'february'  => 'Февраль (Бирдин айы)',
'march'     => 'Март (Жалган куран)',
'april'     => 'Апрель (Чын куран)',
'may_long'  => 'Май (Бугу)',
'june'      => 'Июнь (Кулжа)',
'july'      => 'Июль (Теке)',
'august'    => 'Август (Баш оона)',
'september' => 'Сентябрь (Аяк оона)',
'october'   => 'Октябрь (Тогуздун айы)',
'november'  => 'Ноябрь (Жетинин айы)',
'december'  => 'Декабрь (Бештин айы)',
'april-gen' => 'Апрель',
'jan'       => 'Янв',
'feb'       => 'Фев',
'mar'       => 'Март',
'apr'       => 'Апр',
'may'       => 'Май',
'jun'       => 'Июнь',
'jul'       => 'Июль',
'aug'       => 'Авг',
'sep'       => 'Сент',
'oct'       => 'Окт',
'nov'       => 'Ноя',
'dec'       => 'Дек',

'about'         => 'Тууралуу',
'cancel'        => 'Жокко чыгаруу',
'qbedit'        => 'Оңдоо',
'qbpageoptions' => 'Бул барак',
'qbpageinfo'    => 'Контекст',
'qbmyoptions'   => 'Барактарым',
'mypage'        => 'Барагым',
'mytalk'        => 'Маегим',
'navigation'    => 'Багыттоо',
'and'           => '&#32;жана',

'errorpagetitle'   => 'Жаңылыш',
'tagline'          => '{{SITENAME}} дан',
'help'             => 'Жардам',
'search'           => 'Издөө',
'searchbutton'     => 'Изде',
'go'               => 'Таап бер',
'history_short'    => 'Тарыхчасы',
'printableversion' => 'Басма үлгүсү',
'permalink'        => 'Туруктуу шилтеме',
'edit'             => 'Оңдоо',
'editthispage'     => 'Бул баракты оңдо',
'delete'           => 'Өчүрүү',
'deletethispage'   => 'Бул баракты өчүрүп кой',
'protect'          => 'Коргоо',
'newpage'          => 'Жаңы барак',
'personaltools'    => 'Жеке аспаптар',
'talk'             => 'Баарлашуу',
'toolbox'          => 'Аспап кутусу',
'otherlanguages'   => 'Башка тилдерде',
'jumptonavigation' => 'багыттоо',
'jumptosearch'     => 'издөө',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} тууралуу',
'aboutpage'            => 'Project:тууралуу',
'copyrightpagename'    => '{{SITENAME}} автордук укугу',
'copyrightpage'        => '{{ns:project}}:Автордук укуктар',
'currentevents'        => 'Учурдагы окуялар',
'currentevents-url'    => 'Project:Учурдагы окуялар',
'edithelppage'         => 'Help:Оңдоо',
'mainpage'             => 'Башбарак',
'mainpage-description' => 'Башбарак',
'portal'               => 'Жамаат порталы',
'portal-url'           => 'Project:Жамаат порталы',

'youhavenewmessages'      => 'Сизге $1 ($2) бар.',
'newmessageslink'         => 'жаңы билдирүүлөр',
'youhavenewmessagesmulti' => 'Сизге $1 жаңы кат бар.',
'editsection'             => 'оңдоо',
'editold'                 => 'оңдоо',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Макала',
'nstab-user'      => 'Колдонуучунун барагы',
'nstab-project'   => 'Долбоор барагы',
'nstab-image'     => 'Файл',
'nstab-mediawiki' => 'Билдирүү',
'nstab-template'  => 'Нуска',
'nstab-help'      => 'Жардам',
'nstab-category'  => 'Категория',

# General errors
'error'         => 'Жаңылыш',
'viewsource'    => 'Байкоо',
'viewsourcefor' => '$1 үчүн',

# Login and logout pages
'welcomecreation'    => '== Кош келиңиз, $1! ==

Сиз катоодон өттүңүз. {{SITENAME}} түзөө киргизүүнү унутпаңыз.',
'yourname'           => 'Колдонуучунун аты',
'yourpassword'       => 'Сырсөз',
'yourpasswordagain'  => 'Сырсөздү кайтадан жазыңыз',
'yourdomainname'     => 'Сиздин домен',
'login'              => 'Кирүү',
'userlogin'          => 'Кирүү / Каттоо',
'logout'             => 'Чыгуу',
'userlogout'         => 'Чыгуу',
'createaccountmail'  => 'Электрондук дарек боюнча',
'youremail'          => 'Электрондук почта:',
'username'           => 'Колдонуучунун аты:',
'uid'                => 'Колдонуучунун ID си:',
'yourrealname'       => 'Анык атыңыз:',
'yourlanguage'       => 'Тил:',
'yourvariant'        => 'Вариант:',
'yournick'           => 'Такма атыңыз:',
'wrongpassword'      => 'Ката сырсөз киргизилди. Кайтадан аракет кылып көрүңүз.',
'wrongpasswordempty' => 'Сырсөз киргизилген жок. Кайтадан аракет кылып көрүңүз.',
'mailmypassword'     => 'Сырсөздү электрондук дарегиме жибер',
'emailconfirmlink'   => 'Электрондук дарегиңизди ырастаңыз',
'accountcreated'     => 'Катталды',
'loginlanguagelabel' => 'Тил: $1',

# Password reset dialog
'oldpassword' => 'Эски сырсөз:',
'newpassword' => 'Жаңы сырсөз:',

# Edit pages
'summary'            => 'Кыска түшүндүрүү:',
'savearticle'        => 'Баракты сактап кой',
'whitelistedittitle' => 'Оңдоо үчүн катоодон өтүү зарыл',
'accmailtitle'       => 'Сырсөз жөнөтүлдү.',
'accmailtext'        => '"$1" үчүн сырсөз $2 ге жөнөтүлдү.',
'newarticle'         => '(Жаңы)',
'editing'            => 'Оңдоо $1',
'yourtext'           => 'Текстиңиз',
'yourdiff'           => 'Айырмалар',

# History pages
'next'       => 'кийинки',
'last'       => 'соңку',
'deletedrev' => '[өчүрүлдү]',

# Diffs
'difference' => '(Оңдоолордун айырмасы)',

# Search results
'powersearch' => 'Издөө',

# Preferences page
'preferences'        => 'Түзөө',
'changepassword'     => 'Сырсөздү өзгөртүү',
'dateformat'         => 'Датанын форматы',
'datetime'           => 'Дата жана убакыт',
'math_unknown_error' => 'белгисиз ката',
'prefs-rc'           => 'Соңку өзгөрүүлөр',
'prefs-watchlist'    => 'Байкоо тизме',
'saveprefs'          => 'Сактап кой',
'textboxsize'        => 'Оңдоо',
'searchresultshead'  => 'Издөө',
'localtime'          => 'Жергиликтүү убакыт',
'files'              => 'Файлдар',

# Groups
'group'            => 'Топ:',
'group-bureaucrat' => 'Бюрократтар',

'group-bureaucrat-member' => 'Бюрократ',

# Recent changes
'recentchanges' => 'Соңку өзгөрүүлөр',
'diff'          => 'айырма',
'hist'          => 'тарыхы',
'newpageletter' => 'Ж',

# Recent changes linked
'recentchangeslinked' => 'Тиешелүү өзгөрүүлөр',

# Upload
'upload'            => 'Файл жүктөө',
'uploadbtn'         => 'Файл жүктөө',
'filedesc'          => 'Кыска түшүндүрмө',
'fileuploadsummary' => 'Кыска түшүндүрмө:',
'uploadedfiles'     => 'Жүктөлгөн файлдар',
'savefile'          => 'Файлды сактап кой',

'license' => 'Лицензиялоо:',

# Special:ListFiles
'listfiles' => 'Файлдар тизмеси',

# File description page
'imagelinks' => 'Шилтемелер',

# Unused templates
'unusedtemplates'    => 'Колдонулбаган нускалар',
'unusedtemplateswlh' => 'Башка шилтемелер',

# Random page
'randompage' => 'Тушкелди макала',

# Statistics
'statistics'              => 'Статистика',
'statistics-header-users' => 'Колдонуучулардын статистикасы',

# Miscellaneous special pages
'unusedcategories' => 'Колдонулбаган категориялар',
'unusedimages'     => 'Колдонулбаган файлдар',
'shortpages'       => 'Кыска макалалар',
'listusers'        => 'Колдонуучулар тизмеси',
'newpages'         => 'Жаңы барактар',
'ancientpages'     => 'Эң эски барактар',
'move'             => 'Аталышын өзгөртүү',

# Special:Log
'specialloguserlabel'  => 'Колдонуучу:',
'speciallogtitlelabel' => 'Аталышы:',

# Special:AllPages
'allpages'       => 'Бардык барактар',
'nextpage'       => 'Кийинки барак ($1)',
'allpagesfrom'   => '-дан башталган барактарды көрсөт:',
'allarticles'    => 'Бардык макалалар',
'allpagesprev'   => 'Мурунку',
'allpagesnext'   => 'Кийинки',
'allpagessubmit' => 'Алга',
'allpagesprefix' => '- префикси менен барактарды көрсөт',

# E-mail user
'emailfrom'    => '- дан',
'emailmessage' => 'Кат',

# Watchlist
'watchlist'         => 'Байкоо тизмем',
'watchlistfor'      => "('''$1''' үчүн)",
'watchnologin'      => 'Катталган жок',
'addedwatch'        => 'Байкоо тизмеге кошумчаланды',
'watch'             => 'Байкоо',
'watchlistcontains' => 'Байкоо тизмеңизде $1 {{PLURAL:$1|барак бар|барак бар}}.',
'wlshowlast'        => 'Соңку $1 саат $2 күн $3 көрсөт.',

'changed' => 'өзгөртүлдү',
'created' => 'түзүлдү',

# Delete
'deletepage'     => 'Баракты өчүрүп кой',
'confirm'        => 'Ырастоо',
'actioncomplete' => 'Иш-аракет жыйынтыкталды',
'deletedarticle' => 'өчүрүлдү "[[$1]]"',
'deletecomment'  => 'Өчүрүү үчүн себептер',

# Restrictions (nouns)
'restriction-edit' => 'Оңдоо',

# Undelete
'undeletebtn'     => 'Калыбына келтир',
'undeletecomment' => 'Түшүндүрмө:',

# Contributions
'contributions' => 'Колдонуучунун салымдары',
'mycontris'     => 'Салымдарым',

# What links here
'whatlinkshere' => 'Жетелеме шилтемелер',

# Block/unblock
'ipaddress'      => 'IP дареги',
'ipbreason'      => 'Себеп',
'ipbotheroption' => 'башка',
'contribslink'   => 'салымдары',

# Move page
'movereason'              => 'Себеп',
'delete_and_move_confirm' => 'Ооба, бул баракты өчүр',

# Namespace 8 related
'allmessages'         => 'Система билдирүүлөрү',
'allmessagesname'     => 'Аталышы',
'allmessagescurrent'  => 'Учурдагы текст',
'allmessagesmodified' => 'Өзгөрүүгө учурагандарды гана көрсөт',

# Attribution
'others' => 'башкалар',

# Browsing diffs
'nextdiff' => 'Кийинки айырма →',

# Special:NewFiles
'newimages' => 'Жаңы файлдардын галлереясы',
'ilsubmit'  => 'Издөө',
'bydate'    => 'Күнү боюнча',

# EXIF tags
'exif-artist'   => 'Автор',
'exif-contrast' => 'Контраст',

'exif-meteringmode-0'   => 'Белгисиз',
'exif-meteringmode-255' => 'Башка',

'exif-focalplaneresolutionunit-2' => 'дюйм',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'баары',
'watchlistall2'    => 'баары',

# E-mail address confirmation
'confirmemail'          => 'Электрондук даректи ырастоо',
'confirmemail_loggedin' => 'Электрондук дарегиңиз ырасталды.',

# Special:Version
'version' => 'Версия', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Атайын барактар',

);

==> mediawiki-1.15.5p3.tgz: mediawiki/languages/messages/MessagesKy.php <==
<?php
/** Kirghiz (Кыргызча)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Aidabishkek
 */

$messages = array(
'underline-always' => 'Ар дайым',
'underline-never'  => 'Эч качан',

# Dates
'sunday'    => 'Жекшемби',
'monday'    => 'Дүйшөмбү',
'tuesday'   => 'Шейшемби',
'wednesday' => 'Шаршемби',
'thursday'  => 'Бейшемби',
'friday'    => 'Жума',
'saturday'  => 'Ишемби',
'wed'       => 'Шарш.',
'january'   => 'Январь (Үчтүн айы)',
'february'  => 'Февраль (Бирдин айы)',
'march'     => 'Март (Жалган куран)',
'april'     => 'Апрель (Чын куран)',
'may_long'  => 'Май (Бугу)',
'june'      => 'Июнь (Кулжа)',
'july'      => 'Июль (Теке)',
'august'    => 'Август (Баш оона)',
'september' => 'Сентябрь (Аяк оона)',
'october'   => 'Октябрь (Тогуздун айы)',
'november'  => 'Ноябрь (Жетинин айы)',
'december'  => 'Декабрь (Бештин айы)',
'april-gen' => 'Апрель',
'jan'       => 'Янв',
'feb'       => 'Фев',
'mar'       => 'Март',
'apr'       => 'Апр',
'may'       => 'Май',
'jun'       => 'Июнь',
'jul'       => 'Июль',
'aug'       => 'Авг',
'sep'       => 'Сент',
'oct'       => 'Окт',
'nov'       => 'Ноя',
'dec'       => 'Дек',

'about'         => 'Тууралуу',
'cancel'        => 'Жокко чыгаруу',
'qbedit'        => 'Оңдоо',
'qbpageoptions' => 'Бул барак',
'qbpageinfo'    => 'Контекст',
'qbmyoptions'   => 'Барактарым',
'mypage'        => 'Барагым',
'mytalk'        => 'Маегим',
'navigation'    => 'Багыттоо',
'and'           => '&#32;жана',

'errorpagetitle'   => 'Жаңылыш',
'tagline'          => '{{SITENAME}} дан',
'help'             => 'Жардам',
'search'           => 'Издөө',
'searchbutton'     => 'Изде',
'go'               => 'Таап бер',
'history_short'    => 'Тарыхчасы',
'printableversion' => 'Басма үлгүсү',
'permalink'        => 'Туруктуу шилтеме',
'edit'             => 'Оңдоо',
'editthispage'     => 'Бул баракты оңдо',
'delete'           => 'Өчүрүү',
'deletethispage'   => 'Бул баракты өчүрүп кой',
'protect'          => 'Коргоо',
'newpage'          => 'Жаңы барак',
'personaltools'    => 'Жеке аспаптар',
'talk'             => 'Баарлашуу',
'toolbox'          => 'Аспап кутусу',
'otherlanguages'   => 'Башка тилдерде',
'jumptonavigation' => 'багыттоо',
'jumptosearch'     => 'издөө',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} тууралуу',
'aboutpage'            => 'Project:тууралуу',
'copyrightpagename'    => '{{SITENAME}} автордук укугу',
'copyrightpage'        => '{{ns:project}}:Автордук укуктар',
'currentevents'        => 'Учурдагы окуялар',
'currentevents-url'    => 'Project:Учурдагы окуялар',
'edithelppage'         => 'Help:Оңдоо',
'mainpage'             => 'Башбарак',
'mainpage-description' => 'Башбарак',
'portal'               => 'Жамаат порталы',
'portal-url'           => 'Project:Жамаат порталы',

'youhavenewmessages'      => 'Сизге $1 ($2) бар.',
'newmessageslink'         => 'жаңы билдирүүлөр',
'youhavenewmessagesmulti' => 'Сизге $1 жаңы кат бар.',
'editsection'             => 'оңдоо',
'editold'                 => 'оңдоо',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Макала',
'nstab-user'      => 'Колдонуучунун барагы',
'nstab-project'   => 'Долбоор барагы',
'nstab-image'     => 'Файл',
'nstab-mediawiki' => 'Билдирүү',
'nstab-template'  => 'Нуска',
'nstab-help'      => 'Жардам',
'nstab-category'  => 'Категория',

# General errors
'error'         => 'Жаңылыш',
'viewsource'    => 'Байкоо',
'viewsourcefor' => '$1 үчүн',

# Login and logout pages
'welcomecreation'    => '== Кош келиңиз, $1! ==

Сиз катоодон өттүңүз. {{SITENAME}} түзөө киргизүүнү унутпаңыз.',
'yourname'           => 'Колдонуучунун аты',
'yourpassword'       => 'Сырсөз',
'yourpasswordagain'  => 'Сырсөздү кайтадан жазыңыз',
'yourdomainname'     => 'Сиздин домен',
'login'              => 'Кирүү',
'userlogin'          => 'Кирүү / Каттоо',
'logout'             => 'Чыгуу',
'userlogout'         => 'Чыгуу',
'createaccountmail'  => 'Электрондук дарек боюнча',
'youremail'          => 'Электрондук почта:',
'username'           => 'Колдонуучунун аты:',
'uid'                => 'Колдонуучунун ID си:',
'yourrealname'       => 'Анык атыңыз:',
'yourlanguage'       => 'Тил:',
'yourvariant'        => 'Вариант:',
'yournick'           => 'Такма атыңыз:',
'wrongpassword'      => 'Ката сырсөз киргизилди. Кайтадан аракет кылып көрүңүз.',
'wrongpasswordempty' => 'Сырсөз киргизилген жок. Кайтадан аракет кылып көрүңүз.',
'mailmypassword'     => 'Сырсөздү электрондук дарегиме жибер',
'emailconfirmlink'   => 'Электрондук дарегиңизди ырастаңыз',
'accountcreated'     => 'Катталды',
'loginlanguagelabel' => 'Тил: $1',

# Password reset dialog
'oldpassword' => 'Эски сырсөз:',
'newpassword' => 'Жаңы сырсөз:',

# Edit pages
'summary'            => 'Кыска түшүндүрүү:',
'savearticle'        => 'Баракты сактап кой',
'whitelistedittitle' => 'Оңдоо үчүн катоодон өтүү зарыл',
'accmailtitle'       => 'Сырсөз жөнөтүлдү.',
'accmailtext'        => '"$1" үчүн сырсөз $2 ге жөнөтүлдү.',
'newarticle'         => '(Жаңы)',
'editing'            => 'Оңдоо $1',
'yourtext'           => 'Текстиңиз',
'yourdiff'           => 'Айырмалар',

# History pages
'next'       => 'кийинки',
'last'       => 'соңку',
'deletedrev' => '[өчүрүлдү]',

# Diffs
'difference' => '(Оңдоолордун айырмасы)',

# Search results
'powersearch' => 'Издөө',

# Preferences page
'preferences'        => 'Түзөө',
'changepassword'     => 'Сырсөздү өзгөртүү',
'dateformat'         => 'Датанын форматы',
'datetime'           => 'Дата жана убакыт',
'math_unknown_error' => 'белгисиз ката',
'prefs-rc'           => 'Соңку өзгөрүүлөр',
'prefs-watchlist'    => 'Байкоо тизме',
'saveprefs'          => 'Сактап кой',
'textboxsize'        => 'Оңдоо',
'searchresultshead'  => 'Издөө',
'localtime'          => 'Жергиликтүү убакыт',
'files'              => 'Файлдар',

# Groups
'group'            => 'Топ:',
'group-bureaucrat' => 'Бюрократтар',

'group-bureaucrat-member' => 'Бюрократ',

# Recent changes
'recentchanges' => 'Соңку өзгөрүүлөр',
'diff'          => 'айырма',
'hist'          => 'тарыхы',
'newpageletter' => 'Ж',

# Recent changes linked
'recentchangeslinked' => 'Тиешелүү өзгөрүүлөр',

# Upload
'upload'            => 'Файл жүктөө',
'uploadbtn'         => 'Файл жүктөө',
'filedesc'          => 'Кыска түшүндүрмө',
'fileuploadsummary' => 'Кыска түшүндүрмө:',
'uploadedfiles'     => 'Жүктөлгөн файлдар',
'savefile'          => 'Файлды сактап кой',

'license' => 'Лицензиялоо:',

# Special:ListFiles
'listfiles' => 'Файлдар тизмеси',

# File description page
'imagelinks' => 'Шилтемелер',

# Unused templates
'unusedtemplates'    => 'Колдонулбаган нускалар',
'unusedtemplateswlh' => 'Башка шилтемелер',

# Random page
'randompage' => 'Тушкелди макала',

# Statistics
'statistics'              => 'Статистика',
'statistics-header-users' => 'Колдонуучулардын статистикасы',

# Miscellaneous special pages
'unusedcategories' => 'Колдонулбаган категориялар',
'unusedimages'     => 'Колдонулбаган файлдар',
'shortpages'       => 'Кыска макалалар',
'listusers'        => 'Колдонуучулар тизмеси',
'newpages'         => 'Жаңы барактар',
'ancientpages'     => 'Эң эски барактар',
'move'             => 'Аталышын өзгөртүү',

# Special:Log
'specialloguserlabel'  => 'Колдонуучу:',
'speciallogtitlelabel' => 'Аталышы:',

# Special:AllPages
'allpages'       => 'Бардык барактар',
'nextpage'       => 'Кийинки барак ($1)',
'allpagesfrom'   => '-дан башталган барактарды көрсөт:',
'allarticles'    => 'Бардык макалалар',
'allpagesprev'   => 'Мурунку',
'allpagesnext'   => 'Кийинки',
'allpagessubmit' => 'Алга',
'allpagesprefix' => '- префикси менен барактарды көрсөт',

# E-mail user
'emailfrom'    => '- дан',
'emailmessage' => 'Кат',

# Watchlist
'watchlist'         => 'Байкоо тизмем',
'watchlistfor'      => "('''$1''' үчүн)",
'watchnologin'      => 'Катталган жок',
'addedwatch'        => 'Байкоо тизмеге кошумчаланды',
'watch'             => 'Байкоо',
'watchlistcontains' => 'Байкоо тизмеңизде $1 {{PLURAL:$1|барак бар|барак бар}}.',
'wlshowlast'        => 'Соңку $1 саат $2 күн $3 көрсөт.',

'changed' => 'өзгөртүлдү',
'created' => 'түзүлдү',

# Delete
'deletepage'     => 'Баракты өчүрүп кой',
'confirm'        => 'Ырастоо',
'actioncomplete' => 'Иш-аракет жыйынтыкталды',
'deletedarticle' => 'өчүрүлдү "[[$1]]"',
'deletecomment'  => 'Себеп',

# Restrictions (nouns)
'restriction-edit' => 'Оңдоо',

# Undelete
'undeletebtn'     => 'Калыбына келтир',
'undeletecomment' => 'Түшүндүрмө:',

# Contributions
'contributions' => 'Колдонуучунун салымдары',
'mycontris'     => 'Салымдарым',

# What links here
'whatlinkshere' => 'Жетелеме шилтемелер',

# Block/unblock
'ipaddress'      => 'IP дареги',
'ipbreason'      => 'Себеп',
'ipbotheroption' => 'башка',
'contribslink'   => 'салымдары',

# Move page
'movereason'              => 'Себеп',
'delete_and_move_confirm' => 'Ооба, бул баракты өчүр',

# Namespace 8 related
'allmessages'         => 'Система билдирүүлөрү',
'allmessagesname'     => 'Аталышы',
'allmessagescurrent'  => 'Учурдагы текст',
'allmessagesmodified' => 'Өзгөрүүгө учурагандарды гана көрсөт',

# Attribution
'others' => 'башкалар',

# Browsing diffs
'nextdiff' => 'Кийинки айырма →',

# Special:NewFiles
'newimages' => 'Жаңы файлдардын галлереясы',
'ilsubmit'  => 'Издөө',
'bydate'    => 'Күнү боюнча',

# EXIF tags
'exif-artist'   => 'Автор',
'exif-contrast' => 'Контраст',

'exif-meteringmode-0'   => 'Белгисиз',
'exif-meteringmode-255' => 'Башка',

'exif-focalplaneresolutionunit-2' => 'дюйм',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'баары',
'watchlistall2'    => 'баары',

# E-mail address confirmation
'confirmemail'          => 'Электрондук даректи ырастоо',
'confirmemail_loggedin' => 'Электрондук дарегиңиз ырасталды.',

# Special:Version
'version' => 'Версия', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Атайын барактар',

);
